@@ -6,8 +6,6 @@ import Data.ByteString (ByteString)
 import qualified Data.ByteString.Lazy as BL (ByteString)
 import qualified Network.HTTP.Client as H
 import Network.HTTP.Date
-import Network.HTTP.Types
-import Network.Wai
 import Network.Wai.Handler.Warp (FileInfo(..))
 import Network.Wai.Application.Classic.Path
 
@@ -16,8 +14,6 @@ import Network.Wai.Application.Classic.Path
 data ClassicAppSpec = ClassicAppSpec {
     -- | Name specified to Server: in HTTP response.
     softwareName :: ByteString
-    -- | A function for logging. The third argument is a body size.
-  , logger :: Request -> Status -> Maybe Integer -> IO ()
     -- | A function to get HTTP's GMT Date.
   , statusFileDir :: Path
   }
@@ -105,29 +101,4 @@ data RevProxyRoute = RevProxyRoute {
 
 ----------------------------------------------------------------
 
-data RspSpec = RspSpec {
-    -- | Response status.
-    rspStatus :: Status
-    -- | Response body.
-  , rspBody :: RspBody
-  } deriving (Eq,Show)
-
-data RspBody =
-    NoBody
-  | BodyStatus
-  | BodyFileNoBody ResponseHeaders
-  | BodyFile ResponseHeaders Path Range
-  deriving (Eq,Show)
-
-data Range =
-    -- | Entire file showing its file size
-    Entire Integer
-    -- | A part of a file taking offset and length
-  | Part Integer -- offset
-         Integer -- length
-         Integer -- total
-  deriving (Eq,Show)
-
-----------------------------------------------------------------
-
 type Lang = Path -> Path
